"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.faceAuth = faceAuth;
exports.init = init;
var _reactNative = require("react-native");
var _reactNativeFs = _interopRequireDefault(require("react-native-fs"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const LINKING_ERROR = `The package 'mosip-inji-face-sdk' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo managed workflow\n';
const MosipInjiFaceSdk = _reactNative.NativeModules.MosipInjiFaceSdk ? _reactNative.NativeModules.MosipInjiFaceSdk : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
function faceAuth(capturedImage, vcImage) {
  return MosipInjiFaceSdk.faceAuth(capturedImage, vcImage);
}
async function init(url, overrideCache) {
  try {
    console.log('inside inji face sdk init function, url is - ' + url);
    const fileDir = `${_reactNativeFs.default.CachesDirectoryPath}/model.tflite`;
    var fileExists = await _reactNativeFs.default.exists(fileDir);
    if (fileExists) {
      // compare checksum and verify if file downloaded successfully
      var checksum = await _reactNativeFs.default.readFile(`${_reactNativeFs.default.CachesDirectoryPath}/checksum.txt`);
      checksum = checksum.replace(/\s/g, "");
      var fileData = await _reactNativeFs.default.hash(fileDir, 'sha256');
      console.log('file exists......so comparing checksum');
      if (checksum !== fileData) {
        fileExists = false;
      } else {
        return Promise.resolve(true);
      }
    }
    if (!fileExists || overrideCache) {
      let txtDownloadRes = await _reactNativeFs.default.downloadFile({
        fromUrl: url + '/model.txt',
        toFile: `${_reactNativeFs.default.CachesDirectoryPath}/checksum.txt`
      }).promise;
      console.log('Checksum file download status code = ' + txtDownloadRes.statusCode);
      let downloadRes = await _reactNativeFs.default.downloadFile({
        fromUrl: url + '/model.tflite',
        toFile: fileDir
      }).promise;
      console.log('Model File download size = ' + downloadRes.bytesWritten);
      var checksum = await _reactNativeFs.default.readFile(`${_reactNativeFs.default.CachesDirectoryPath}/checksum.txt`);
      checksum = checksum.replace(/\s/g, "");
      var fileData = await _reactNativeFs.default.hash(fileDir, 'sha256');
      console.log('checksum calculated from file = ' + fileData);
      console.log('checksum received from server = ' + checksum.replace(/\s/g, ""));
      if (fileData === checksum) {
        return Promise.resolve(true);
      }
    }
  } catch (e) {
    console.error('Error occured downloading model from - ' + url);
    console.error(e);
  }
  return Promise.resolve(false);
}
//# sourceMappingURL=index.js.map